==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/ManagementNetworkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Configuration to be used to setup the management network.
 * @property infrastructureVpnConfiguration Configuration for infrastructure vpn.
 * @property workloadVpnConfiguration Configuration for workload vpn.
 */
public data class ManagementNetworkConfigurationArgs(
    public val infrastructureVpnConfiguration: Output<VpnConfigurationPropertiesArgs>,
    public val workloadVpnConfiguration: Output<VpnConfigurationPropertiesArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs.builder()
            .infrastructureVpnConfiguration(
                infrastructureVpnConfiguration.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .workloadVpnConfiguration(
                workloadVpnConfiguration.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagementNetworkConfigurationArgs].
 */
@PulumiTagMarker
public class ManagementNetworkConfigurationArgsBuilder internal constructor() {
    private var infrastructureVpnConfiguration: Output<VpnConfigurationPropertiesArgs>? = null

    private var workloadVpnConfiguration: Output<VpnConfigurationPropertiesArgs>? = null

    /**
     * @param value Configuration for infrastructure vpn.
     */
    @JvmName("mfeixaawqfmekumy")
    public suspend
    fun infrastructureVpnConfiguration(`value`: Output<VpnConfigurationPropertiesArgs>) {
        this.infrastructureVpnConfiguration = value
    }

    /**
     * @param value Configuration for workload vpn.
     */
    @JvmName("panocehhdedvlqai")
    public suspend fun workloadVpnConfiguration(`value`: Output<VpnConfigurationPropertiesArgs>) {
        this.workloadVpnConfiguration = value
    }

    /**
     * @param value Configuration for infrastructure vpn.
     */
    @JvmName("kumtgqhscuntycxh")
    public suspend fun infrastructureVpnConfiguration(`value`: VpnConfigurationPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.infrastructureVpnConfiguration = mapped
    }

    /**
     * @param argument Configuration for infrastructure vpn.
     */
    @JvmName("kudyhixbosyobjxk")
    public suspend
    fun infrastructureVpnConfiguration(argument: suspend VpnConfigurationPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = VpnConfigurationPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.infrastructureVpnConfiguration = mapped
    }

    /**
     * @param value Configuration for workload vpn.
     */
    @JvmName("jressfvgumgsfjmt")
    public suspend fun workloadVpnConfiguration(`value`: VpnConfigurationPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workloadVpnConfiguration = mapped
    }

    /**
     * @param argument Configuration for workload vpn.
     */
    @JvmName("kmvaqatojoidyghv")
    public suspend
    fun workloadVpnConfiguration(argument: suspend VpnConfigurationPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = VpnConfigurationPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.workloadVpnConfiguration = mapped
    }

    internal fun build(): ManagementNetworkConfigurationArgs = ManagementNetworkConfigurationArgs(
        infrastructureVpnConfiguration = infrastructureVpnConfiguration ?: throw
            PulumiNullFieldException("infrastructureVpnConfiguration"),
        workloadVpnConfiguration = workloadVpnConfiguration ?: throw
            PulumiNullFieldException("workloadVpnConfiguration"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/ManagementNetworkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Configuration to be used to setup the management network.
 * @property infrastructureVpnConfiguration Configuration for infrastructure vpn.
 * @property workloadVpnConfiguration Configuration for workload vpn.
 */
public data class ManagementNetworkConfigurationArgs(
    public val infrastructureVpnConfiguration: Output<VpnConfigurationPropertiesArgs>,
    public val workloadVpnConfiguration: Output<VpnConfigurationPropertiesArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.ManagementNetworkConfigurationArgs.builder()
            .infrastructureVpnConfiguration(
                infrastructureVpnConfiguration.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .workloadVpnConfiguration(
                workloadVpnConfiguration.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagementNetworkConfigurationArgs].
 */
@PulumiTagMarker
public class ManagementNetworkConfigurationArgsBuilder internal constructor() {
    private var infrastructureVpnConfiguration: Output<VpnConfigurationPropertiesArgs>? = null

    private var workloadVpnConfiguration: Output<VpnConfigurationPropertiesArgs>? = null

    /**
     * @param value Configuration for infrastructure vpn.
     */
    @JvmName("ajvhgmvwjysfkqbb")
    public suspend
    fun infrastructureVpnConfiguration(`value`: Output<VpnConfigurationPropertiesArgs>) {
        this.infrastructureVpnConfiguration = value
    }

    /**
     * @param value Configuration for workload vpn.
     */
    @JvmName("eshasxkfaxfiojnn")
    public suspend fun workloadVpnConfiguration(`value`: Output<VpnConfigurationPropertiesArgs>) {
        this.workloadVpnConfiguration = value
    }

    /**
     * @param value Configuration for infrastructure vpn.
     */
    @JvmName("alpshpmckgaguayo")
    public suspend fun infrastructureVpnConfiguration(`value`: VpnConfigurationPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.infrastructureVpnConfiguration = mapped
    }

    /**
     * @param argument Configuration for infrastructure vpn.
     */
    @JvmName("ccrnkqyybfhgohao")
    public suspend
    fun infrastructureVpnConfiguration(argument: suspend VpnConfigurationPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = VpnConfigurationPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.infrastructureVpnConfiguration = mapped
    }

    /**
     * @param value Configuration for workload vpn.
     */
    @JvmName("isbylppccrcvjbrw")
    public suspend fun workloadVpnConfiguration(`value`: VpnConfigurationPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.workloadVpnConfiguration = mapped
    }

    /**
     * @param argument Configuration for workload vpn.
     */
    @JvmName("yhvxmwwgtrlurfkh")
    public suspend
    fun workloadVpnConfiguration(argument: suspend VpnConfigurationPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = VpnConfigurationPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.workloadVpnConfiguration = mapped
    }

    internal fun build(): ManagementNetworkConfigurationArgs = ManagementNetworkConfigurationArgs(
        infrastructureVpnConfiguration = infrastructureVpnConfiguration ?: throw
            PulumiNullFieldException("infrastructureVpnConfiguration"),
        workloadVpnConfiguration = workloadVpnConfiguration ?: throw
            PulumiNullFieldException("workloadVpnConfiguration"),
    )
}
